==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/mail_menu.php <==
<?php
//==============================================================
// Program Name		: mail_menu
// File Name		: mail_menu.php
//--------------------------------------------------------------
// Date 			: 2002/02/15
// Author			: AQUAPLAN NETWORKS
//--------------------------------------------------------------
// Note				: Żҥ᡼
//					: 
//--------------------------------------------------------------
// Rev. 			: 
//					: 
//==============================================================


require("jetjob.inc");
require("mail_common.inc");


//==============================================================
// Function Name	: Print_Header
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Menu()
{
	global $JJ_USERNAME, $JJ_OUTPUT_CHARSET;//桼̾
	global $current_dir;
	global $JJ_IMG_ROOT;
	global $dir_array;


	print("<HTML>\n");
	print("<HEAD>\n");
	print("<meta http-equiv=\"content-type\" content=\"text/html;charset=$JJ_OUTPUT_CHARSET\">\n");
	printf("<TITLE></TITLE>\n", TITLE);
	printf("<LINK REL=STYLESHEET TYPE=\"text/css\" HREF=\"%s\">\n", CSS_FILE);
	print("</HEAD>\n");
	print("<BODY>\n");

	////////////////////////////////////
	// ˥塼ɽ
	print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n");
	print("<tr valign=\"top\">\n");
	print("<td>\n");

	print("<table border=\"0\" cellpadding=\"10\" cellspacing=\"0\" width=\"170\" class=\"color02\">\n");

			reset($dir_array);

			$db = new DB_Test;

			// ߤΥե
			if (empty($current_dir)) $current_dir = "Ȣ";

			print("<tr>\n");
			print("<td>\n");
			print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n");

			print("<tr><td colspan=\"3\" nowrap>\n");
			printf("<img height=\"13\" width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_GIF);
			print("᡼ե<br><hr></td>\n");
			print("</tr>\n");


			$array_count = count($dir_array);
			$cnt = 0;
			while (list($name, $path) = each($dir_array)) 
			{
				// ᡼Υ
				$query = sprintf("SELECT mail_id FROM mail_index where member_id = '%s' and mail_read = 0 and file_path like '%s' ORDER BY datetime DESC",
							CURRENT_USER_ID, $dir_array[$name] . "/%");
				$db->query($query);
				$mail_count = $db->nf();

				/***
				if ($current_dir == $name)
					print("<tr width=\"10%%\"><td align=\"right\"></td>\n");
				else
					print("<tr width=\"10%%\"><td align=\"right\">&nbsp;</td>\n");
				***/
				print("<tr width=\"10%%\"><td align=\"right\">&nbsp;</td>\n");
				//if ($name == "Ȣ")
				if ($current_dir == $name)
				{
					printf("<td width=\"20%%\"><img height=\"20\" width=\"20\" src=\"%s\" hspace=\"5\" align=\"absmiddle\"></td>\n", FOLD_OPEN_GIF);//SEND_GIF);
					print("<td width=\"70%%\">\n");
					printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><b>%s</b></a></td>\n", 
								MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name);
				}
				else
				{
					printf("<td width=\"20%%\"><img height=\"20\" width=\"20\" src=\"%s\" hspace=\"5\" align=\"absmiddle\"></td>\n", FOLD_CLOSE_GIF);//RECV_GIF);
					if ($mail_count > 0)
					{
						print("<td width=\"70%%\">\n");
						printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><font size=\"-1\">%s(%d)</font></a></td>\n", 
									MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name, $mail_count);
					}
					else
					{
						print("<td width=\"70%%\">\n");
						printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><font size=\"-1\">%s</font></a></td>\n", 
									MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name);
					}
				}
				print("</td></tr>\n");

				$cnt++;
			}
			print("</table></td></tr>\n");
			$db->Close();

	print("</table>\n");
	print("</td></tr></table>\n");

	print("</BODY>\n");
	print("</HTML>\n");
}


////////////////////////////////////////////////////////////////


//==============================================================
// Function Name	: 
//--------------------------------------------------------------
// Note				: 
//					: 
//==============================================================

	Login_Start(PG_NAME());//å

//printf("[%s]\n", $current_dir);
	////////////////////////////////////////////////
	// ȥ᡼ե̾Υǥ
	if (isset($current_dir))
	{
		$current_dir = urldecode($current_dir);
	}
	else
	{
		if (isset($current_dir_saved))
			$current_dir = $current_dir_saved;
		else
			$current_dir = "Ȣ";
	}

	$dir_array = Get_UserFolder();
	Print_menu();

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/mail_menu.php <==
<?php
//==============================================================
// Program Name		: mail_menu
// File Name		: mail_menu.php
//--------------------------------------------------------------
// Date 			: 2002/02/15
// Author			: AQUAPLAN NETWORKS
//--------------------------------------------------------------
// Note				: Żҥ᡼
//					: 
//--------------------------------------------------------------
// Rev. 			: 
//					: 
//==============================================================


require("jetjob.inc.php");
require("mail_common.inc");


//==============================================================
// Function Name	: Print_Header
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Menu()
{
	global $JJ_USERNAME, $JJ_OUTPUT_CHARSET;//桼̾
	global $current_dir;
	global $JJ_IMG_ROOT;
	global $dir_array;


	print("<HTML>\n");
	print("<HEAD>\n");
	print("<meta http-equiv=\"content-type\" content=\"text/html;charset=$JJ_OUTPUT_CHARSET\">\n");
	printf("<TITLE></TITLE>\n", TITLE);
	printf("<LINK REL=STYLESHEET TYPE=\"text/css\" HREF=\"%s\">\n", CSS_FILE);
	print("</HEAD>\n");
	print("<BODY>\n");

	////////////////////////////////////
	// ˥塼ɽ
	print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n");
	print("<tr valign=\"top\">\n");
	print("<td>\n");

	print("<table border=\"0\" cellpadding=\"10\" cellspacing=\"0\" width=\"170\" class=\"color02\">\n");

			reset($dir_array);

			$db = new DB_Test;

			// ߤΥե
			if (empty($current_dir)) $current_dir = "Ȣ";

			print("<tr>\n");
			print("<td>\n");
			print("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n");

			print("<tr><td colspan=\"3\" nowrap>\n");
			printf("<img height=\"13\" width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_GIF);
			print("᡼ե<br><hr></td>\n");
			print("</tr>\n");


			$array_count = count($dir_array);
			$cnt = 0;
			while (list($name, $path) = each($dir_array)) 
			{
				// ᡼Υ
				$query = sprintf("SELECT mail_id FROM mail_index where member_id = '%s' and mail_read = 0 and file_path like '%s' ORDER BY datetime DESC",
							CURRENT_USER_ID, $dir_array[$name] . "/%");
				$db->query($query);
				$mail_count = $db->nf();

				/***
				if ($current_dir == $name)
					print("<tr width=\"10%%\"><td align=\"right\"></td>\n");
				else
					print("<tr width=\"10%%\"><td align=\"right\">&nbsp;</td>\n");
				***/
				print("<tr width=\"10%%\"><td align=\"right\">&nbsp;</td>\n");
				//if ($name == "Ȣ")
				if ($current_dir == $name)
				{
					printf("<td width=\"20%%\"><img height=\"20\" width=\"20\" src=\"%s\" hspace=\"5\" align=\"absmiddle\"></td>\n", FOLD_OPEN_GIF);//SEND_GIF);
					print("<td width=\"70%%\">\n");
					printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><b>%s</b></a></td>\n", 
								MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name);
				}
				else
				{
					printf("<td width=\"20%%\"><img height=\"20\" width=\"20\" src=\"%s\" hspace=\"5\" align=\"absmiddle\"></td>\n", FOLD_CLOSE_GIF);//RECV_GIF);
					if ($mail_count > 0)
					{
						print("<td width=\"70%%\">\n");
						printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><font size=\"-1\">%s(%d)</font></a></td>\n", 
									MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name, $mail_count);
					}
					else
					{
						print("<td width=\"70%%\">\n");
						printf("<a href=\"%s?current_dir=%s\" target=\"content\" onClick=\"location.href='%s?current_dir=%s';\"><font size=\"-1\">%s</font></a></td>\n", 
									MAIL_MAIN_PROGRAM, urlencode($name), PG_NAME(), urlencode($name), $name);
					}
				}
				print("</td></tr>\n");

				$cnt++;
			}
			print("</table></td></tr>\n");
			$db->Close();

	print("</table>\n");
	print("</td></tr></table>\n");

	print("</BODY>\n");
	print("</HTML>\n");
}


////////////////////////////////////////////////////////////////


//==============================================================
// Function Name	: 
//--------------------------------------------------------------
// Note				: 
//					: 
//==============================================================

	Login_Start(PG_NAME());//å

//printf("[%s]\n", $current_dir);
	////////////////////////////////////////////////
	// ȥ᡼ե̾Υǥ
	if (isset($current_dir))
	{
		$current_dir = urldecode($current_dir);
	}
	else
	{
		if (isset($current_dir_saved))
			$current_dir = $current_dir_saved;
		else
			$current_dir = "Ȣ";
	}

	$dir_array = Get_UserFolder();
	Print_menu();
